package com.easefun.polyv.webview.activity;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.net.http.SslError;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.webkit.SslErrorHandler;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.RelativeLayout;
import android.widget.Toast;

import com.easefun.polyv.webview.R;
import com.easefun.polyv.webview.core.AdvancedWebView;
import com.easefun.polyv.webview.core.VideoEnabledWebChromeClient;

public class WebViewActivity extends Activity implements AdvancedWebView.Listener {
	private static final String TAG = "WebViewActivity";
	private AdvancedWebView mWebView;
	private VideoEnabledWebChromeClient mWebChromeClient;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_web_view);

		mWebView = findViewById(R.id.webView);
		RelativeLayout nonVideoLayout = findViewById(R.id.nonVideoLayout);
		RelativeLayout videoLayout = findViewById(R.id.videoLayout);
		View loadingView = getLayoutInflater().inflate(R.layout.view_loading_video, null);

		mWebView.setListener(this, this);
		mWebView.setGeolocationEnabled(false);
		mWebView.setMixedContentAllowed(getIntent().getBooleanExtra("isMixedContentAllowed", true));
		mWebView.setCookiesEnabled(true);
		mWebView.setThirdPartyCookiesEnabled(true);
		mWebView.setWebViewClient(new InsideWebViewClient());

		mWebChromeClient = new VideoEnabledWebChromeClient(nonVideoLayout, videoLayout, loadingView, mWebView) // See all available constructors...
		{
			// Subscribe to standard events, such as onProgressChanged()...
			@Override
			public void onProgressChanged(WebView view, int progress)
			{
				// Your code...
			}
		};
		mWebChromeClient.setOnToggledFullscreen(new VideoEnabledWebChromeClient.ToggledFullscreenCallback()
		{
			@Override
			public void toggledFullscreen(boolean fullscreen)
			{
				// Your code to handle the full-screen change, for example showing and hiding the title bar. Example:
				if (fullscreen)
				{
					WindowManager.LayoutParams attrs = getWindow().getAttributes();
					attrs.flags |= WindowManager.LayoutParams.FLAG_FULLSCREEN;
					attrs.flags |= WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON;
					getWindow().setAttributes(attrs);
					getWindow().getDecorView().setSystemUiVisibility(View.SYSTEM_UI_FLAG_LOW_PROFILE);
				}
				else
				{
					WindowManager.LayoutParams attrs = getWindow().getAttributes();
					attrs.flags &= ~WindowManager.LayoutParams.FLAG_FULLSCREEN;
					attrs.flags &= ~WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON;
					getWindow().setAttributes(attrs);
					getWindow().getDecorView().setSystemUiVisibility(View.SYSTEM_UI_FLAG_VISIBLE);
				}
			}
		});

		mWebView.setWebChromeClient(mWebChromeClient);

		if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR1) {
			mWebView.getSettings().setMediaPlaybackRequiresUserGesture(false);
		}

		mWebView.addHttpHeader("X-Requested-With", "");
		mWebView.loadUrl(getIntent().getStringExtra("url"));
	}

	private class InsideWebViewClient extends WebViewClient {
		@Override
		public void onPageFinished(WebView view, String url) {
			Toast.makeText(WebViewActivity.this, "Finished loading", Toast.LENGTH_SHORT).show();
		}

		@Override
		// Force links to be opened inside WebView and not in Default Browser
		// Thanks http://stackoverflow.com/a/33681975/1815624
		public boolean shouldOverrideUrlLoading(WebView view, String url) {
			view.loadUrl(url);
			return true;
		}

		@Override
		public void onReceivedSslError(WebView view, SslErrorHandler handler, SslError error) {
			handler.proceed();
		}
	}

	@SuppressLint("NewApi")
	@Override
	protected void onResume() {
		mWebView.onResume();
		mWebView.resumeTimers();
		// ...
		super.onResume();
	}

	@SuppressLint("NewApi")
	@Override
	protected void onPause() {
		mWebView.onPause();
		mWebView.pauseTimers();
		// ...
		super.onPause();
	}

	@Override
	protected void onDestroy() {
		if (mWebView != null) {
			mWebView.loadDataWithBaseURL(null, "", "text/html", "utf-8", null);
			mWebView.clearHistory();
			((ViewGroup) mWebView.getParent()).removeView(mWebView);
			mWebView.destroy();
			mWebView = null;
		}

		// ...
		super.onDestroy();
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent intent) {
		super.onActivityResult(requestCode, resultCode, intent);
		mWebView.onActivityResult(requestCode, resultCode, intent);
		// ...
	}

	@Override
	public void onBackPressed() {
		if (!mWebView.onBackPressed()) { return; }
		// ...
		super.onBackPressed();
	}

	@Override
	public void onPageStarted(String url, Bitmap favicon) {
		if (mWebView != null) {
			mWebView.setVisibility(View.INVISIBLE);
		}
	}

	@Override
	public void onPageFinished(String url) {
		if (mWebView != null) {
			mWebView.setVisibility(View.VISIBLE);
		}
	}

	@Override
	public void onPageError(int errorCode, String description, String failingUrl) {
		String msg = "onPageError(errorCode = "+errorCode+",  description = "+description+",  failingUrl = "+failingUrl+")";
		Toast.makeText(WebViewActivity.this, msg, Toast.LENGTH_SHORT).show();
		Log.e(TAG, msg);
	}

	@Override
	public void onDownloadRequested(String url, String suggestedFilename, String mimeType, long contentLength, String contentDisposition, String userAgent) {
		String msg = "onDownloadRequested(url = "+url+",  suggestedFilename = "+suggestedFilename+",  mimeType = "+mimeType+",  contentLength = "+contentLength+",  contentDisposition = "+contentDisposition+",  userAgent = "+userAgent+")";
		Toast.makeText(WebViewActivity.this, msg, Toast.LENGTH_LONG).show();
		Log.i(TAG, msg);

		/*if (AdvancedWebView.handleDownload(this, url, suggestedFilename)) {
			// download successfully handled
		}
		else {
			// download couldn't be handled because user has disabled download manager app on the device
		}*/
	}

	@Override
	public void onExternalPageRequest(String url) {
		String msg = "onExternalPageRequest(url = "+url+")";
		Toast.makeText(WebViewActivity.this, msg, Toast.LENGTH_SHORT).show();
		Log.i(TAG, msg);
	}

}
